from typing import Optional

from typing import List

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.v2025_r0.enterprise_configuration_item_boolean_v2025_r0 import (
    EnterpriseConfigurationItemBooleanV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.enterprise_configuration_item_v2025_r0 import (
    EnterpriseConfigurationItemV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.enterprise_configuration_item_string_v2025_r0 import (
    EnterpriseConfigurationItemStringV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.enterprise_configuration_item_integer_v2025_r0 import (
    EnterpriseConfigurationItemIntegerV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.external_collab_security_settings_v2025_r0 import (
    ExternalCollabSecuritySettingsV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.keysafe_settings_v2025_r0 import (
    KeysafeSettingsV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.custom_session_duration_group_item_v2025_r0 import (
    CustomSessionDurationGroupItemV2025R0,
)

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class EnterpriseConfigurationSecurityV2025R0LastPasswordResetAtField(
    EnterpriseConfigurationItemV2025R0
):
    def __init__(
        self,
        *,
        value: Optional[DateTime] = None,
        is_used: Optional[bool] = None,
        **kwargs
    ):
        """
        :param value: When an enterprise password reset was last applied., defaults to None
        :type value: Optional[DateTime], optional
        :param is_used: Indicates whether a configuration is used for a given enterprise., defaults to None
        :type is_used: Optional[bool], optional
        """
        super().__init__(is_used=is_used, **kwargs)
        self.value = value


class EnterpriseConfigurationSecurityV2025R0ExternalCollabMultiFactorAuthSettingsField(
    EnterpriseConfigurationItemV2025R0
):
    def __init__(
        self,
        *,
        value: Optional[ExternalCollabSecuritySettingsV2025R0] = None,
        is_used: Optional[bool] = None,
        **kwargs
    ):
        """
        :param is_used: Indicates whether a configuration is used for a given enterprise., defaults to None
        :type is_used: Optional[bool], optional
        """
        super().__init__(is_used=is_used, **kwargs)
        self.value = value


class EnterpriseConfigurationSecurityV2025R0KeysafeField(
    EnterpriseConfigurationItemV2025R0
):
    def __init__(
        self,
        *,
        value: Optional[KeysafeSettingsV2025R0] = None,
        is_used: Optional[bool] = None,
        **kwargs
    ):
        """
        :param is_used: Indicates whether a configuration is used for a given enterprise., defaults to None
        :type is_used: Optional[bool], optional
        """
        super().__init__(is_used=is_used, **kwargs)
        self.value = value


class EnterpriseConfigurationSecurityV2025R0CustomSessionDurationGroupsField(
    EnterpriseConfigurationItemV2025R0
):
    def __init__(
        self,
        *,
        value: Optional[List[CustomSessionDurationGroupItemV2025R0]] = None,
        is_used: Optional[bool] = None,
        **kwargs
    ):
        """
        :param is_used: Indicates whether a configuration is used for a given enterprise., defaults to None
        :type is_used: Optional[bool], optional
        """
        super().__init__(is_used=is_used, **kwargs)
        self.value = value


class EnterpriseConfigurationSecurityV2025R0EnforcedMfaFrequencyFieldValueField(
    BaseObject
):
    def __init__(
        self, *, days: Optional[int] = None, hours: Optional[int] = None, **kwargs
    ):
        """
        :param days: Number of days before the user is required to authenticate again., defaults to None
        :type days: Optional[int], optional
        :param hours: Number of hours before the user is required to authenticate again., defaults to None
        :type hours: Optional[int], optional
        """
        super().__init__(**kwargs)
        self.days = days
        self.hours = hours


class EnterpriseConfigurationSecurityV2025R0EnforcedMfaFrequencyField(
    EnterpriseConfigurationItemV2025R0
):
    def __init__(
        self,
        *,
        value: Optional[
            EnterpriseConfigurationSecurityV2025R0EnforcedMfaFrequencyFieldValueField
        ] = None,
        is_used: Optional[bool] = None,
        **kwargs
    ):
        """
        :param is_used: Indicates whether a configuration is used for a given enterprise., defaults to None
        :type is_used: Optional[bool], optional
        """
        super().__init__(is_used=is_used, **kwargs)
        self.value = value


class EnterpriseConfigurationSecurityV2025R0(BaseObject):
    def __init__(
        self,
        *,
        is_managed_user_signup_enabled: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        is_managed_user_signup_notification_enabled: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        is_managed_user_signup_corporate_email_enabled: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        is_new_user_notification_daily_digest_enabled: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        is_managed_user_email_change_disabled: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        is_multi_factor_auth_required: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        is_weak_password_prevention_enabled: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        is_password_leak_detection_enabled: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        last_password_reset_at: Optional[
            EnterpriseConfigurationSecurityV2025R0LastPasswordResetAtField
        ] = None,
        is_password_request_notification_enabled: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        is_password_change_notification_enabled: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        is_strong_password_for_ext_collab_enabled: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        is_managed_user_migration_disabled: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        join_link: Optional[EnterpriseConfigurationItemStringV2025R0] = None,
        join_url: Optional[EnterpriseConfigurationItemStringV2025R0] = None,
        failed_login_attempts_to_trigger_admin_notification: Optional[
            EnterpriseConfigurationItemIntegerV2025R0
        ] = None,
        password_min_length: Optional[EnterpriseConfigurationItemIntegerV2025R0] = None,
        password_min_uppercase_characters: Optional[
            EnterpriseConfigurationItemIntegerV2025R0
        ] = None,
        password_min_numeric_characters: Optional[
            EnterpriseConfigurationItemIntegerV2025R0
        ] = None,
        password_min_special_characters: Optional[
            EnterpriseConfigurationItemIntegerV2025R0
        ] = None,
        password_reset_frequency: Optional[
            EnterpriseConfigurationItemStringV2025R0
        ] = None,
        previous_password_reuse_limit: Optional[
            EnterpriseConfigurationItemStringV2025R0
        ] = None,
        session_duration: Optional[EnterpriseConfigurationItemStringV2025R0] = None,
        external_collab_multi_factor_auth_settings: Optional[
            EnterpriseConfigurationSecurityV2025R0ExternalCollabMultiFactorAuthSettingsField
        ] = None,
        keysafe: Optional[EnterpriseConfigurationSecurityV2025R0KeysafeField] = None,
        is_custom_session_duration_enabled: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        custom_session_duration_value: Optional[
            EnterpriseConfigurationItemStringV2025R0
        ] = None,
        custom_session_duration_groups: Optional[
            EnterpriseConfigurationSecurityV2025R0CustomSessionDurationGroupsField
        ] = None,
        multi_factor_auth_type: Optional[
            EnterpriseConfigurationItemStringV2025R0
        ] = None,
        enforced_mfa_frequency: Optional[
            EnterpriseConfigurationSecurityV2025R0EnforcedMfaFrequencyField
        ] = None,
        **kwargs
    ):
        super().__init__(**kwargs)
        self.is_managed_user_signup_enabled = is_managed_user_signup_enabled
        self.is_managed_user_signup_notification_enabled = (
            is_managed_user_signup_notification_enabled
        )
        self.is_managed_user_signup_corporate_email_enabled = (
            is_managed_user_signup_corporate_email_enabled
        )
        self.is_new_user_notification_daily_digest_enabled = (
            is_new_user_notification_daily_digest_enabled
        )
        self.is_managed_user_email_change_disabled = (
            is_managed_user_email_change_disabled
        )
        self.is_multi_factor_auth_required = is_multi_factor_auth_required
        self.is_weak_password_prevention_enabled = is_weak_password_prevention_enabled
        self.is_password_leak_detection_enabled = is_password_leak_detection_enabled
        self.last_password_reset_at = last_password_reset_at
        self.is_password_request_notification_enabled = (
            is_password_request_notification_enabled
        )
        self.is_password_change_notification_enabled = (
            is_password_change_notification_enabled
        )
        self.is_strong_password_for_ext_collab_enabled = (
            is_strong_password_for_ext_collab_enabled
        )
        self.is_managed_user_migration_disabled = is_managed_user_migration_disabled
        self.join_link = join_link
        self.join_url = join_url
        self.failed_login_attempts_to_trigger_admin_notification = (
            failed_login_attempts_to_trigger_admin_notification
        )
        self.password_min_length = password_min_length
        self.password_min_uppercase_characters = password_min_uppercase_characters
        self.password_min_numeric_characters = password_min_numeric_characters
        self.password_min_special_characters = password_min_special_characters
        self.password_reset_frequency = password_reset_frequency
        self.previous_password_reuse_limit = previous_password_reuse_limit
        self.session_duration = session_duration
        self.external_collab_multi_factor_auth_settings = (
            external_collab_multi_factor_auth_settings
        )
        self.keysafe = keysafe
        self.is_custom_session_duration_enabled = is_custom_session_duration_enabled
        self.custom_session_duration_value = custom_session_duration_value
        self.custom_session_duration_groups = custom_session_duration_groups
        self.multi_factor_auth_type = multi_factor_auth_type
        self.enforced_mfa_frequency = enforced_mfa_frequency



from enum import Enum

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.file_base import FileBase

from box_sdk_gen.schemas.folder_base import FolderBase

from box_sdk_gen.schemas.web_link_base import WebLinkBase

from box_sdk_gen.schemas.app_item import AppItem

from box_sdk_gen.schemas.app_item_associated_item import AppItemAssociatedItem

from box_sdk_gen.box.errors import BoxSDKError


class AppItemAssociationTypeField(str, Enum):
    APP_ITEM_ASSOCIATION = 'app_item_association'


class AppItemAssociation(BaseObject):
    _discriminator = 'type', {'app_item_association'}

    def __init__(
        self,
        id: str,
        app_item: AppItem,
        item: AppItemAssociatedItem,
        *,
        type: AppItemAssociationTypeField = AppItemAssociationTypeField.APP_ITEM_ASSOCIATION,
        **kwargs
    ):
        """
        :param id: The unique identifier for this app item association.
        :type id: str
        :param type: The value will always be `app_item_association`., defaults to AppItemAssociationTypeField.APP_ITEM_ASSOCIATION
        :type type: AppItemAssociationTypeField, optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.app_item = app_item
        self.item = item
        self.type = type



from enum import Enum

from typing import Optional

from typing import List

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.user_base import UserBase

from box_sdk_gen.schemas.group_base import GroupBase

from box_sdk_gen.schemas.ai_agent_allowed_entity import AiAgentAllowedEntity

from box_sdk_gen.schemas.ai_studio_agent_ask import AiStudioAgentAsk

from box_sdk_gen.schemas.ai_studio_agent_text_gen import AiStudioAgentTextGen

from box_sdk_gen.schemas.ai_studio_agent_extract import AiStudioAgentExtract

from box_sdk_gen.box.errors import BoxSDKError


class CreateAiAgentTypeField(str, Enum):
    AI_AGENT = 'ai_agent'


class CreateAiAgent(BaseObject):
    _discriminator = 'type', {'ai_agent'}

    def __init__(
        self,
        name: str,
        access_state: str,
        *,
        type: CreateAiAgentTypeField = CreateAiAgentTypeField.AI_AGENT,
        icon_reference: Optional[str] = None,
        allowed_entities: Optional[List[AiAgentAllowedEntity]] = None,
        ask: Optional[AiStudioAgentAsk] = None,
        text_gen: Optional[AiStudioAgentTextGen] = None,
        extract: Optional[AiStudioAgentExtract] = None,
        **kwargs
    ):
        """
                :param name: The name of the AI Agent.
                :type name: str
                :param access_state: The state of the AI Agent. Possible values are: `enabled`, `disabled`, and `enabled_for_selected_users`.
                :type access_state: str
                :param type: The type of agent used to handle queries., defaults to CreateAiAgentTypeField.AI_AGENT
                :type type: CreateAiAgentTypeField, optional
                :param icon_reference: The icon reference of the AI Agent. It should have format of the URL `https://cdn01.boxcdn.net/app-assets/aistudio/avatars/<file_name>`
        where possible values of `file_name` are: `logo_boxAi.png`,`logo_stamp.png`,`logo_legal.png`,`logo_finance.png`,`logo_config.png`,`logo_handshake.png`,`logo_analytics.png`,`logo_classification.png`., defaults to None
                :type icon_reference: Optional[str], optional
                :param allowed_entities: List of allowed users or groups., defaults to None
                :type allowed_entities: Optional[List[AiAgentAllowedEntity]], optional
        """
        super().__init__(**kwargs)
        self.name = name
        self.access_state = access_state
        self.type = type
        self.icon_reference = icon_reference
        self.allowed_entities = allowed_entities
        self.ask = ask
        self.text_gen = text_gen
        self.extract = extract



from box_sdk_gen.internal.utils import *

from box_sdk_gen.internal.logging import *

from box_sdk_gen.internal.errors import *

from box_sdk_gen.internal.base_object import *

from box_sdk_gen.internal.null_value import *



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class WebLinkBaseTypeField(str, Enum):
    WEB_LINK = 'web_link'


class WebLinkBase(BaseObject):
    _discriminator = 'type', {'web_link'}

    def __init__(
        self,
        id: str,
        *,
        type: WebLinkBaseTypeField = WebLinkBaseTypeField.WEB_LINK,
        etag: Optional[str] = None,
        **kwargs
    ):
        """
                :param id: The unique identifier for this web link.
                :type id: str
                :param type: The value will always be `web_link`., defaults to WebLinkBaseTypeField.WEB_LINK
                :type type: WebLinkBaseTypeField, optional
                :param etag: The entity tag of this web link. Used with `If-Match`
        headers., defaults to None
                :type etag: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type
        self.etag = etag



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from typing import List

from box_sdk_gen.box.errors import BoxSDKError


class ShieldListContentIntegrationV2025R0TypeField(str, Enum):
    INTEGRATION = 'integration'


class ShieldListContentIntegrationV2025R0IntegrationsField(BaseObject):
    def __init__(self, *, id: Optional[str] = None, **kwargs):
        """
        :param id: The ID of the integration., defaults to None
        :type id: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.id = id


class ShieldListContentIntegrationV2025R0(BaseObject):
    _discriminator = 'type', {'integration'}

    def __init__(
        self,
        integrations: List[ShieldListContentIntegrationV2025R0IntegrationsField],
        *,
        type: ShieldListContentIntegrationV2025R0TypeField = ShieldListContentIntegrationV2025R0TypeField.INTEGRATION,
        **kwargs
    ):
        """
        :param integrations: List of integration.
        :type integrations: List[ShieldListContentIntegrationV2025R0IntegrationsField]
        :param type: The type of content in the shield list., defaults to ShieldListContentIntegrationV2025R0TypeField.INTEGRATION
        :type type: ShieldListContentIntegrationV2025R0TypeField, optional
        """
        super().__init__(**kwargs)
        self.integrations = integrations
        self.type = type



from enum import Enum

from box_sdk_gen.internal.base_object import BaseObject

from typing import Optional

from typing import List

from box_sdk_gen.schemas.v2025_r0.file_reference_v2025_r0 import FileReferenceV2025R0

from box_sdk_gen.schemas.v2025_r0.file_version_base_v2025_r0 import (
    FileVersionBaseV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.doc_gen_document_generation_data_v2025_r0 import (
    DocGenDocumentGenerationDataV2025R0,
)

from box_sdk_gen.box.errors import BoxSDKError


class DocGenBatchCreateRequestV2025R0DestinationFolderTypeField(str, Enum):
    FOLDER = 'folder'


class DocGenBatchCreateRequestV2025R0DestinationFolderField(BaseObject):
    _discriminator = 'type', {'folder'}

    def __init__(
        self,
        id: str,
        *,
        type: DocGenBatchCreateRequestV2025R0DestinationFolderTypeField = DocGenBatchCreateRequestV2025R0DestinationFolderTypeField.FOLDER,
        **kwargs
    ):
        """
        :param id: ID of the folder.
        :type id: str
        :param type: The value will always be `folder`., defaults to DocGenBatchCreateRequestV2025R0DestinationFolderTypeField.FOLDER
        :type type: DocGenBatchCreateRequestV2025R0DestinationFolderTypeField, optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type


class DocGenBatchCreateRequestV2025R0(BaseObject):
    def __init__(
        self,
        file: FileReferenceV2025R0,
        input_source: str,
        destination_folder: DocGenBatchCreateRequestV2025R0DestinationFolderField,
        output_type: str,
        document_generation_data: List[DocGenDocumentGenerationDataV2025R0],
        *,
        file_version: Optional[FileVersionBaseV2025R0] = None,
        **kwargs
    ):
        """
        :param input_source: Source of input. The value has to be `api` for all the API-based document generation requests.
        :type input_source: str
        :param output_type: Type of the output file.
        :type output_type: str
        """
        super().__init__(**kwargs)
        self.file = file
        self.input_source = input_source
        self.destination_folder = destination_folder
        self.output_type = output_type
        self.document_generation_data = document_generation_data
        self.file_version = file_version



from typing import Optional

from box_sdk_gen.schemas.folder_base import FolderBaseTypeField

from box_sdk_gen.schemas.folder_base import FolderBase

from box_sdk_gen.box.errors import BoxSDKError


class FolderMini(FolderBase):
    def __init__(
        self,
        id: str,
        *,
        sequence_id: Optional[str] = None,
        name: Optional[str] = None,
        etag: Optional[str] = None,
        type: FolderBaseTypeField = FolderBaseTypeField.FOLDER,
        **kwargs
    ):
        """
                :param id: The unique identifier that represent a folder.

        The ID for any folder can be determined
        by visiting a folder in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/folders/123`
        the `folder_id` is `123`.
                :type id: str
                :param name: The name of the folder., defaults to None
                :type name: Optional[str], optional
                :param etag: The HTTP `etag` of this folder. This can be used within some API
        endpoints in the `If-Match` and `If-None-Match` headers to only
        perform changes on the folder if (no) changes have happened., defaults to None
                :type etag: Optional[str], optional
                :param type: The value will always be `folder`., defaults to FolderBaseTypeField.FOLDER
                :type type: FolderBaseTypeField, optional
        """
        super().__init__(id=id, etag=etag, type=type, **kwargs)
        self.sequence_id = sequence_id
        self.name = name



from enum import Enum

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class SignRequestSignerInputZip4ValidationValidationTypeField(str, Enum):
    ZIP_4 = 'zip_4'


class SignRequestSignerInputZip4Validation(BaseObject):
    def __init__(
        self,
        *,
        validation_type: SignRequestSignerInputZip4ValidationValidationTypeField = SignRequestSignerInputZip4ValidationValidationTypeField.ZIP_4,
        **kwargs
    ):
        """
        :param validation_type: Validates that the text input is a ZIP+4 code., defaults to SignRequestSignerInputZip4ValidationValidationTypeField.ZIP_4
        :type validation_type: SignRequestSignerInputZip4ValidationValidationTypeField, optional
        """
        super().__init__(**kwargs)
        self.validation_type = validation_type



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class StatusSkillCardTypeField(str, Enum):
    SKILL_CARD = 'skill_card'


class StatusSkillCardSkillCardTypeField(str, Enum):
    STATUS = 'status'


class StatusSkillCardSkillCardTitleField(BaseObject):
    def __init__(self, message: str, *, code: Optional[str] = None, **kwargs):
        """
        :param message: The actual title to show in the UI.
        :type message: str
        :param code: An optional identifier for the title., defaults to None
        :type code: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.message = message
        self.code = code


class StatusSkillCardStatusCodeField(str, Enum):
    INVOKED = 'invoked'
    PROCESSING = 'processing'
    SUCCESS = 'success'
    TRANSIENT_FAILURE = 'transient_failure'
    PERMANENT_FAILURE = 'permanent_failure'


class StatusSkillCardStatusField(BaseObject):
    def __init__(
        self,
        code: StatusSkillCardStatusCodeField,
        *,
        message: Optional[str] = None,
        **kwargs
    ):
        """
                :param code: A code for the status of this Skill invocation. By
        default each of these will have their own accompanied
        messages. These can be adjusted by setting the `message`
        value on this object.
                :type code: StatusSkillCardStatusCodeField
                :param message: A custom message that can be provided with this status.
        This will be shown in the web app to the end user., defaults to None
                :type message: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.code = code
        self.message = message


class StatusSkillCardSkillTypeField(str, Enum):
    SERVICE = 'service'


class StatusSkillCardSkillField(BaseObject):
    _discriminator = 'type', {'service'}

    def __init__(
        self,
        id: str,
        *,
        type: StatusSkillCardSkillTypeField = StatusSkillCardSkillTypeField.SERVICE,
        **kwargs
    ):
        """
                :param id: A custom identifier that represent the service that
        applied this metadata.
                :type id: str
                :param type: The value will always be `service`., defaults to StatusSkillCardSkillTypeField.SERVICE
                :type type: StatusSkillCardSkillTypeField, optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type


class StatusSkillCardInvocationTypeField(str, Enum):
    SKILL_INVOCATION = 'skill_invocation'


class StatusSkillCardInvocationField(BaseObject):
    _discriminator = 'type', {'skill_invocation'}

    def __init__(
        self,
        id: str,
        *,
        type: StatusSkillCardInvocationTypeField = StatusSkillCardInvocationTypeField.SKILL_INVOCATION,
        **kwargs
    ):
        """
                :param id: A custom identifier that represent the instance of
        the service that applied this metadata. For example,
        if your `image-recognition-service` runs on multiple
        nodes, this field can be used to identify the ID of
        the node that was used to apply the metadata.
                :type id: str
                :param type: The value will always be `skill_invocation`., defaults to StatusSkillCardInvocationTypeField.SKILL_INVOCATION
                :type type: StatusSkillCardInvocationTypeField, optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type


class StatusSkillCard(BaseObject):
    _discriminator = 'skill_card_type', {'status'}

    def __init__(
        self,
        status: StatusSkillCardStatusField,
        skill: StatusSkillCardSkillField,
        invocation: StatusSkillCardInvocationField,
        *,
        created_at: Optional[DateTime] = None,
        type: StatusSkillCardTypeField = StatusSkillCardTypeField.SKILL_CARD,
        skill_card_type: StatusSkillCardSkillCardTypeField = StatusSkillCardSkillCardTypeField.STATUS,
        skill_card_title: Optional[StatusSkillCardSkillCardTitleField] = None,
        **kwargs
    ):
        """
                :param status: Sets the status of the skill. This can be used to show a message to the user while the Skill is processing the data, or if it was not able to process the file.
                :type status: StatusSkillCardStatusField
                :param skill: The service that applied this metadata.
                :type skill: StatusSkillCardSkillField
                :param invocation: The invocation of this service, used to track
        which instance of a service applied the metadata.
                :type invocation: StatusSkillCardInvocationField
                :param created_at: The optional date and time this card was created at., defaults to None
                :type created_at: Optional[DateTime], optional
                :param type: The value will always be `skill_card`., defaults to StatusSkillCardTypeField.SKILL_CARD
                :type type: StatusSkillCardTypeField, optional
                :param skill_card_type: The value will always be `status`., defaults to StatusSkillCardSkillCardTypeField.STATUS
                :type skill_card_type: StatusSkillCardSkillCardTypeField, optional
                :param skill_card_title: The title of the card., defaults to None
                :type skill_card_title: Optional[StatusSkillCardSkillCardTitleField], optional
        """
        super().__init__(**kwargs)
        self.status = status
        self.skill = skill
        self.invocation = invocation
        self.created_at = created_at
        self.type = type
        self.skill_card_type = skill_card_type
        self.skill_card_title = skill_card_title



from typing import List

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.v2025_r0.external_user_deletion_result_v2025_r0 import (
    ExternalUserDeletionResultV2025R0,
)

from box_sdk_gen.box.errors import BoxSDKError


class ExternalUsersSubmitDeleteJobResponseV2025R0(BaseObject):
    def __init__(self, entries: List[ExternalUserDeletionResultV2025R0], **kwargs):
        """
        :param entries: Array of results of each external user deletion request.
        :type entries: List[ExternalUserDeletionResultV2025R0]
        """
        super().__init__(**kwargs)
        self.entries = entries



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from typing import List

from box_sdk_gen.schemas.device_pinner import DevicePinner

from box_sdk_gen.box.errors import BoxSDKError


class DevicePinnersOrderByField(str, Enum):
    ID = 'id'


class DevicePinnersOrderDirectionField(str, Enum):
    ASC = 'asc'
    DESC = 'desc'


class DevicePinnersOrderField(BaseObject):
    def __init__(
        self,
        *,
        by: Optional[DevicePinnersOrderByField] = None,
        direction: Optional[DevicePinnersOrderDirectionField] = None,
        **kwargs
    ):
        """
        :param by: The field that is ordered by., defaults to None
        :type by: Optional[DevicePinnersOrderByField], optional
        :param direction: The direction to order by, either ascending or descending., defaults to None
        :type direction: Optional[DevicePinnersOrderDirectionField], optional
        """
        super().__init__(**kwargs)
        self.by = by
        self.direction = direction


class DevicePinners(BaseObject):
    def __init__(
        self,
        *,
        entries: Optional[List[DevicePinner]] = None,
        limit: Optional[int] = None,
        next_marker: Optional[int] = None,
        order: Optional[List[DevicePinnersOrderField]] = None,
        **kwargs
    ):
        """
                :param entries: A list of device pins., defaults to None
                :type entries: Optional[List[DevicePinner]], optional
                :param limit: The limit that was used for these entries. This will be the same as the
        `limit` query parameter unless that value exceeded the maximum value
        allowed., defaults to None
                :type limit: Optional[int], optional
                :param next_marker: The marker for the start of the next page of results., defaults to None
                :type next_marker: Optional[int], optional
                :param order: The order by which items are returned., defaults to None
                :type order: Optional[List[DevicePinnersOrderField]], optional
        """
        super().__init__(**kwargs)
        self.entries = entries
        self.limit = limit
        self.next_marker = next_marker
        self.order = order



from enum import Enum

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class RoleVariableTypeField(str, Enum):
    VARIABLE = 'variable'


class RoleVariableVariableTypeField(str, Enum):
    COLLABORATOR_ROLE = 'collaborator_role'


class RoleVariableVariableValueField(str, Enum):
    EDITOR = 'editor'
    VIEWER = 'viewer'
    PREVIEWER = 'previewer'
    UPLOADER = 'uploader'
    PREVIEWER_UPLOADER = 'previewer uploader'
    VIEWER_UPLOADER = 'viewer uploader'
    CO_OWNER = 'co-owner'


class RoleVariable(BaseObject):
    _discriminator = 'type', {'variable'}

    def __init__(
        self,
        variable_value: RoleVariableVariableValueField,
        *,
        type: RoleVariableTypeField = RoleVariableTypeField.VARIABLE,
        variable_type: RoleVariableVariableTypeField = RoleVariableVariableTypeField.COLLABORATOR_ROLE,
        **kwargs
    ):
        """
                :param type: Role object type., defaults to RoleVariableTypeField.VARIABLE
                :type type: RoleVariableTypeField, optional
                :param variable_type: The variable type used
        by the object., defaults to RoleVariableVariableTypeField.COLLABORATOR_ROLE
                :type variable_type: RoleVariableVariableTypeField, optional
        """
        super().__init__(**kwargs)
        self.variable_value = variable_value
        self.type = type
        self.variable_type = variable_type



from enum import Enum

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class DocGenBatchBaseV2025R0TypeField(str, Enum):
    DOCGEN_BATCH = 'docgen_batch'


class DocGenBatchBaseV2025R0(BaseObject):
    _discriminator = 'type', {'docgen_batch'}

    def __init__(
        self,
        id: str,
        *,
        type: DocGenBatchBaseV2025R0TypeField = DocGenBatchBaseV2025R0TypeField.DOCGEN_BATCH,
        **kwargs
    ):
        """
        :param id: The unique identifier that represents a Box Doc Gen batch.
        :type id: str
        :param type: The value will always be `docgen_batch`., defaults to DocGenBatchBaseV2025R0TypeField.DOCGEN_BATCH
        :type type: DocGenBatchBaseV2025R0TypeField, optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.v2025_r0.enterprise_configuration_security_v2025_r0 import (
    EnterpriseConfigurationSecurityV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.enterprise_configuration_content_and_sharing_v2025_r0 import (
    EnterpriseConfigurationContentAndSharingV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.enterprise_configuration_user_settings_v2025_r0 import (
    EnterpriseConfigurationUserSettingsV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.enterprise_configuration_shield_v2025_r0 import (
    EnterpriseConfigurationShieldV2025R0,
)

from box_sdk_gen.box.errors import BoxSDKError


class EnterpriseConfigurationV2025R0TypeField(str, Enum):
    ENTERPRISE_CONFIGURATION = 'enterprise_configuration'


class EnterpriseConfigurationV2025R0(BaseObject):
    _discriminator = 'type', {'enterprise_configuration'}

    def __init__(
        self,
        *,
        id: Optional[str] = None,
        type: Optional[EnterpriseConfigurationV2025R0TypeField] = None,
        security: Optional[EnterpriseConfigurationSecurityV2025R0] = None,
        content_and_sharing: Optional[
            EnterpriseConfigurationContentAndSharingV2025R0
        ] = None,
        user_settings: Optional[EnterpriseConfigurationUserSettingsV2025R0] = None,
        shield: Optional[EnterpriseConfigurationShieldV2025R0] = None,
        **kwargs
    ):
        """
        :param id: The identifier of the enterprise configuration which is the ID of the enterprise., defaults to None
        :type id: Optional[str], optional
        :param type: The value will always be `enterprise_configuration`., defaults to None
        :type type: Optional[EnterpriseConfigurationV2025R0TypeField], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type
        self.security = security
        self.content_and_sharing = content_and_sharing
        self.user_settings = user_settings
        self.shield = shield



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.user_mini import UserMini

from box_sdk_gen.schemas.group_mini import GroupMini

from box_sdk_gen.box.errors import BoxSDKError


class AppItemEventSourceTypeField(str, Enum):
    APP_ITEM = 'app_item'


class AppItemEventSource(BaseObject):
    _discriminator = 'type', {'app_item'}

    def __init__(
        self,
        id: str,
        app_item_type: str,
        *,
        type: AppItemEventSourceTypeField = AppItemEventSourceTypeField.APP_ITEM,
        user: Optional[UserMini] = None,
        group: Optional[GroupMini] = None,
        **kwargs
    ):
        """
        :param id: The id of the `AppItem`.
        :type id: str
        :param app_item_type: The type of the `AppItem`.
        :type app_item_type: str
        :param type: The type of the source that this event represents. Can only be `app_item`., defaults to AppItemEventSourceTypeField.APP_ITEM
        :type type: AppItemEventSourceTypeField, optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.app_item_type = app_item_type
        self.type = type
        self.user = user
        self.group = group



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.ai_studio_agent_long_text_tool import AiStudioAgentLongTextTool

from box_sdk_gen.schemas.ai_studio_agent_basic_text_tool import (
    AiStudioAgentBasicTextTool,
)

from box_sdk_gen.box.errors import BoxSDKError


class AiStudioAgentExtractTypeField(str, Enum):
    AI_AGENT_EXTRACT = 'ai_agent_extract'


class AiStudioAgentExtract(BaseObject):
    _discriminator = 'type', {'ai_agent_extract'}

    def __init__(
        self,
        access_state: str,
        description: str,
        *,
        type: AiStudioAgentExtractTypeField = AiStudioAgentExtractTypeField.AI_AGENT_EXTRACT,
        custom_instructions: Optional[str] = None,
        long_text: Optional[AiStudioAgentLongTextTool] = None,
        basic_text: Optional[AiStudioAgentBasicTextTool] = None,
        basic_image: Optional[AiStudioAgentBasicTextTool] = None,
        **kwargs
    ):
        """
        :param access_state: The state of the AI Agent capability. Possible values are: `enabled` and `disabled`.
        :type access_state: str
        :param description: The description of the AI agent.
        :type description: str
        :param type: The type of AI agent to be used for metadata extraction., defaults to AiStudioAgentExtractTypeField.AI_AGENT_EXTRACT
        :type type: AiStudioAgentExtractTypeField, optional
        :param custom_instructions: Custom instructions for the AI agent., defaults to None
        :type custom_instructions: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.access_state = access_state
        self.description = description
        self.type = type
        self.custom_instructions = custom_instructions
        self.long_text = long_text
        self.basic_text = basic_text
        self.basic_image = basic_image



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import deserialize

from typing import List

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.internal.utils import DateTime

from box_sdk_gen.schemas.webhooks import Webhooks

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.schemas.webhook import Webhook

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData

from box_sdk_gen.internal.utils import compute_webhook_signature

from box_sdk_gen.internal.utils import compare_signatures

from box_sdk_gen.internal.utils import date_time_from_string

from box_sdk_gen.internal.utils import get_epoch_time_in_seconds

from box_sdk_gen.internal.utils import date_time_to_epoch_seconds


class CreateWebhookTargetTypeField(str, Enum):
    FILE = 'file'
    FOLDER = 'folder'


class CreateWebhookTarget(BaseObject):
    _discriminator = 'type', {'file', 'folder'}

    def __init__(
        self,
        *,
        id: Optional[str] = None,
        type: Optional[CreateWebhookTargetTypeField] = None,
        **kwargs
    ):
        """
        :param id: The ID of the item to trigger a webhook., defaults to None
        :type id: Optional[str], optional
        :param type: The type of item to trigger a webhook., defaults to None
        :type type: Optional[CreateWebhookTargetTypeField], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type


class CreateWebhookTriggers(str, Enum):
    FILE_UPLOADED = 'FILE.UPLOADED'
    FILE_PREVIEWED = 'FILE.PREVIEWED'
    FILE_DOWNLOADED = 'FILE.DOWNLOADED'
    FILE_TRASHED = 'FILE.TRASHED'
    FILE_DELETED = 'FILE.DELETED'
    FILE_RESTORED = 'FILE.RESTORED'
    FILE_COPIED = 'FILE.COPIED'
    FILE_MOVED = 'FILE.MOVED'
    FILE_LOCKED = 'FILE.LOCKED'
    FILE_UNLOCKED = 'FILE.UNLOCKED'
    FILE_RENAMED = 'FILE.RENAMED'
    COMMENT_CREATED = 'COMMENT.CREATED'
    COMMENT_UPDATED = 'COMMENT.UPDATED'
    COMMENT_DELETED = 'COMMENT.DELETED'
    TASK_ASSIGNMENT_CREATED = 'TASK_ASSIGNMENT.CREATED'
    TASK_ASSIGNMENT_UPDATED = 'TASK_ASSIGNMENT.UPDATED'
    METADATA_INSTANCE_CREATED = 'METADATA_INSTANCE.CREATED'
    METADATA_INSTANCE_UPDATED = 'METADATA_INSTANCE.UPDATED'
    METADATA_INSTANCE_DELETED = 'METADATA_INSTANCE.DELETED'
    FOLDER_CREATED = 'FOLDER.CREATED'
    FOLDER_RENAMED = 'FOLDER.RENAMED'
    FOLDER_DOWNLOADED = 'FOLDER.DOWNLOADED'
    FOLDER_RESTORED = 'FOLDER.RESTORED'
    FOLDER_DELETED = 'FOLDER.DELETED'
    FOLDER_COPIED = 'FOLDER.COPIED'
    FOLDER_MOVED = 'FOLDER.MOVED'
    FOLDER_TRASHED = 'FOLDER.TRASHED'
    WEBHOOK_DELETED = 'WEBHOOK.DELETED'
    COLLABORATION_CREATED = 'COLLABORATION.CREATED'
    COLLABORATION_ACCEPTED = 'COLLABORATION.ACCEPTED'
    COLLABORATION_REJECTED = 'COLLABORATION.REJECTED'
    COLLABORATION_REMOVED = 'COLLABORATION.REMOVED'
    COLLABORATION_UPDATED = 'COLLABORATION.UPDATED'
    SHARED_LINK_DELETED = 'SHARED_LINK.DELETED'
    SHARED_LINK_CREATED = 'SHARED_LINK.CREATED'
    SHARED_LINK_UPDATED = 'SHARED_LINK.UPDATED'
    SIGN_REQUEST_COMPLETED = 'SIGN_REQUEST.COMPLETED'
    SIGN_REQUEST_DECLINED = 'SIGN_REQUEST.DECLINED'
    SIGN_REQUEST_EXPIRED = 'SIGN_REQUEST.EXPIRED'
    SIGN_REQUEST_SIGNER_EMAIL_BOUNCED = 'SIGN_REQUEST.SIGNER_EMAIL_BOUNCED'
    SIGN_REQUEST_SIGN_SIGNER_SIGNED = 'SIGN_REQUEST.SIGN_SIGNER_SIGNED'
    SIGN_REQUEST_SIGN_DOCUMENT_CREATED = 'SIGN_REQUEST.SIGN_DOCUMENT_CREATED'
    SIGN_REQUEST_SIGN_ERROR_FINALIZING = 'SIGN_REQUEST.SIGN_ERROR_FINALIZING'


class UpdateWebhookByIdTargetTypeField(str, Enum):
    FILE = 'file'
    FOLDER = 'folder'


class UpdateWebhookByIdTarget(BaseObject):
    _discriminator = 'type', {'file', 'folder'}

    def __init__(
        self,
        *,
        id: Optional[str] = None,
        type: Optional[UpdateWebhookByIdTargetTypeField] = None,
        **kwargs
    ):
        """
        :param id: The ID of the item to trigger a webhook., defaults to None
        :type id: Optional[str], optional
        :param type: The type of item to trigger a webhook., defaults to None
        :type type: Optional[UpdateWebhookByIdTargetTypeField], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type


class UpdateWebhookByIdTriggers(str, Enum):
    FILE_UPLOADED = 'FILE.UPLOADED'
    FILE_PREVIEWED = 'FILE.PREVIEWED'
    FILE_DOWNLOADED = 'FILE.DOWNLOADED'
    FILE_TRASHED = 'FILE.TRASHED'
    FILE_DELETED = 'FILE.DELETED'
    FILE_RESTORED = 'FILE.RESTORED'
    FILE_COPIED = 'FILE.COPIED'
    FILE_MOVED = 'FILE.MOVED'
    FILE_LOCKED = 'FILE.LOCKED'
    FILE_UNLOCKED = 'FILE.UNLOCKED'
    FILE_RENAMED = 'FILE.RENAMED'
    COMMENT_CREATED = 'COMMENT.CREATED'
    COMMENT_UPDATED = 'COMMENT.UPDATED'
    COMMENT_DELETED = 'COMMENT.DELETED'
    TASK_ASSIGNMENT_CREATED = 'TASK_ASSIGNMENT.CREATED'
    TASK_ASSIGNMENT_UPDATED = 'TASK_ASSIGNMENT.UPDATED'
    METADATA_INSTANCE_CREATED = 'METADATA_INSTANCE.CREATED'
    METADATA_INSTANCE_UPDATED = 'METADATA_INSTANCE.UPDATED'
    METADATA_INSTANCE_DELETED = 'METADATA_INSTANCE.DELETED'
    FOLDER_CREATED = 'FOLDER.CREATED'
    FOLDER_RENAMED = 'FOLDER.RENAMED'
    FOLDER_DOWNLOADED = 'FOLDER.DOWNLOADED'
    FOLDER_RESTORED = 'FOLDER.RESTORED'
    FOLDER_DELETED = 'FOLDER.DELETED'
    FOLDER_COPIED = 'FOLDER.COPIED'
    FOLDER_MOVED = 'FOLDER.MOVED'
    FOLDER_TRASHED = 'FOLDER.TRASHED'
    WEBHOOK_DELETED = 'WEBHOOK.DELETED'
    COLLABORATION_CREATED = 'COLLABORATION.CREATED'
    COLLABORATION_ACCEPTED = 'COLLABORATION.ACCEPTED'
    COLLABORATION_REJECTED = 'COLLABORATION.REJECTED'
    COLLABORATION_REMOVED = 'COLLABORATION.REMOVED'
    COLLABORATION_UPDATED = 'COLLABORATION.UPDATED'
    SHARED_LINK_DELETED = 'SHARED_LINK.DELETED'
    SHARED_LINK_CREATED = 'SHARED_LINK.CREATED'
    SHARED_LINK_UPDATED = 'SHARED_LINK.UPDATED'
    SIGN_REQUEST_COMPLETED = 'SIGN_REQUEST.COMPLETED'
    SIGN_REQUEST_DECLINED = 'SIGN_REQUEST.DECLINED'
    SIGN_REQUEST_EXPIRED = 'SIGN_REQUEST.EXPIRED'
    SIGN_REQUEST_SIGNER_EMAIL_BOUNCED = 'SIGN_REQUEST.SIGNER_EMAIL_BOUNCED'
    SIGN_REQUEST_SIGN_SIGNER_SIGNED = 'SIGN_REQUEST.SIGN_SIGNER_SIGNED'
    SIGN_REQUEST_SIGN_DOCUMENT_CREATED = 'SIGN_REQUEST.SIGN_DOCUMENT_CREATED'
    SIGN_REQUEST_SIGN_ERROR_FINALIZING = 'SIGN_REQUEST.SIGN_ERROR_FINALIZING'


class WebhooksManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def get_webhooks(
        self,
        *,
        marker: Optional[str] = None,
        limit: Optional[int] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> Webhooks:
        """
                Returns all defined webhooks for the requesting application.

                This API only returns webhooks that are applied to files or folders that are


                owned by the authenticated user. This means that an admin can not see webhooks


                created by a service account unless the admin has access to those folders, and


                vice versa.

                :param marker: Defines the position marker at which to begin returning results. This is
        used when paginating using marker-based pagination.

        This requires `usemarker` to be set to `true`., defaults to None
                :type marker: Optional[str], optional
                :param limit: The maximum number of items to return per page., defaults to None
                :type limit: Optional[int], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {'marker': to_string(marker), 'limit': to_string(limit)}
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join([self.network_session.base_urls.base_url, '/2.0/webhooks']),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, Webhooks)

    def create_webhook(
        self,
        target: CreateWebhookTarget,
        address: str,
        triggers: List[CreateWebhookTriggers],
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> Webhook:
        """
                Creates a webhook.
                :param target: The item that will trigger the webhook.
                :type target: CreateWebhookTarget
                :param address: The URL that is notified by this webhook.
                :type address: str
                :param triggers: An array of event names that this webhook is
        to be triggered for.
                :type triggers: List[CreateWebhookTriggers]
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'target': target,
            'address': address,
            'triggers': triggers,
        }
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join([self.network_session.base_urls.base_url, '/2.0/webhooks']),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, Webhook)

    def get_webhook_by_id(
        self,
        webhook_id: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> Webhook:
        """
                Retrieves a specific webhook.
                :param webhook_id: The ID of the webhook.
        Example: "3321123"
                :type webhook_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/webhooks/',
                        to_string(webhook_id),
                    ]
                ),
                method='GET',
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, Webhook)

    def update_webhook_by_id(
        self,
        webhook_id: str,
        *,
        target: Optional[UpdateWebhookByIdTarget] = None,
        address: Optional[str] = None,
        triggers: Optional[List[UpdateWebhookByIdTriggers]] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> Webhook:
        """
                Updates a webhook.
                :param webhook_id: The ID of the webhook.
        Example: "3321123"
                :type webhook_id: str
                :param target: The item that will trigger the webhook., defaults to None
                :type target: Optional[UpdateWebhookByIdTarget], optional
                :param address: The URL that is notified by this webhook., defaults to None
                :type address: Optional[str], optional
                :param triggers: An array of event names that this webhook is
        to be triggered for., defaults to None
                :type triggers: Optional[List[UpdateWebhookByIdTriggers]], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'target': target,
            'address': address,
            'triggers': triggers,
        }
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/webhooks/',
                        to_string(webhook_id),
                    ]
                ),
                method='PUT',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, Webhook)

    def delete_webhook_by_id(
        self,
        webhook_id: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> None:
        """
                Deletes a webhook.
                :param webhook_id: The ID of the webhook.
        Example: "3321123"
                :type webhook_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/webhooks/',
                        to_string(webhook_id),
                    ]
                ),
                method='DELETE',
                headers=headers_map,
                response_format=ResponseFormat.NO_CONTENT,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return None

    @staticmethod
    def validate_message(
        body: str,
        headers: Dict[str, str],
        primary_key: str,
        *,
        secondary_key: Optional[str] = None,
        max_age: Optional[int] = 600
    ) -> bool:
        """
        Validate a webhook message by verifying the signature and the delivery timestamp
        :param body: The request body of the webhook message
        :type body: str
        :param headers: The headers of the webhook message
        :type headers: Dict[str, str]
        :param primary_key: The primary signature to verify the message with
        :type primary_key: str
        :param secondary_key: The secondary signature to verify the message with, defaults to None
        :type secondary_key: Optional[str], optional
        :param max_age: The maximum age of the message in seconds, defaults to 10 minutes, defaults to 600
        :type max_age: Optional[int], optional
        """
        delivery_timestamp: DateTime = date_time_from_string(
            headers.get('box-delivery-timestamp')
        )
        current_epoch: int = get_epoch_time_in_seconds()
        if (
            current_epoch - max_age > date_time_to_epoch_seconds(delivery_timestamp)
            or date_time_to_epoch_seconds(delivery_timestamp) > current_epoch
        ):
            return False
        if (
            not primary_key == None and not headers.get('box-signature-primary') == None
        ) and compare_signatures(
            expected_signature=compute_webhook_signature(
                body, headers, primary_key, escape_body=False
            ),
            received_signature=headers.get('box-signature-primary'),
        ):
            return True
        if (
            not primary_key == None and not headers.get('box-signature-primary') == None
        ) and compare_signatures(
            expected_signature=compute_webhook_signature(
                body, headers, primary_key, escape_body=True
            ),
            received_signature=headers.get('box-signature-primary'),
        ):
            return True
        if (
            not secondary_key == None
            and not headers.get('box-signature-secondary') == None
        ) and compare_signatures(
            expected_signature=compute_webhook_signature(
                body, headers, secondary_key, escape_body=False
            ),
            received_signature=headers.get('box-signature-secondary'),
        ):
            return True
        if (
            not secondary_key == None
            and not headers.get('box-signature-secondary') == None
        ) and compare_signatures(
            expected_signature=compute_webhook_signature(
                body, headers, secondary_key, escape_body=True
            ),
            received_signature=headers.get('box-signature-secondary'),
        ):
            return True
        return False



from typing import Union

from box_sdk_gen.schemas.ai_agent_reference import AiAgentReference

from box_sdk_gen.schemas.ai_agent_extract import AiAgentExtract

from box_sdk_gen.box.errors import BoxSDKError

AiExtractAgent = Union[AiAgentReference, AiAgentExtract]



from enum import Enum

from box_sdk_gen.internal.base_object import BaseObject

from typing import Optional

from typing import List

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.comments import Comments

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.schemas.comment_full import CommentFull

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData


class CreateCommentItemTypeField(str, Enum):
    FILE = 'file'
    COMMENT = 'comment'


class CreateCommentItem(BaseObject):
    _discriminator = 'type', {'file', 'comment'}

    def __init__(self, id: str, type: CreateCommentItemTypeField, **kwargs):
        """
        :param id: The ID of the item.
        :type id: str
        :param type: The type of the item that this comment will be placed on.
        :type type: CreateCommentItemTypeField
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type


class CommentsManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def get_file_comments(
        self,
        file_id: str,
        *,
        fields: Optional[List[str]] = None,
        limit: Optional[int] = None,
        offset: Optional[int] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> Comments:
        """
                Retrieves a list of comments for a file.
                :param file_id: The unique identifier that represents a file.

        The ID for any file can be determined
        by visiting a file in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/files/123`
        the `file_id` is `123`.
        Example: "12345"
                :type file_id: str
                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested., defaults to None
                :type fields: Optional[List[str]], optional
                :param limit: The maximum number of items to return per page., defaults to None
                :type limit: Optional[int], optional
                :param offset: The offset of the item at which to begin the response.

        Queries with offset parameter value
        exceeding 10000 will be rejected
        with a 400 response., defaults to None
                :type offset: Optional[int], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {
                'fields': to_string(fields),
                'limit': to_string(limit),
                'offset': to_string(offset),
            }
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/files/',
                        to_string(file_id),
                        '/comments',
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, Comments)

    def get_comment_by_id(
        self,
        comment_id: str,
        *,
        fields: Optional[List[str]] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> CommentFull:
        """
                Retrieves the message and metadata for a specific comment, as well

                as information on the user who created the comment.

                :param comment_id: The ID of the comment.
        Example: "12345"
                :type comment_id: str
                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested., defaults to None
                :type fields: Optional[List[str]], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params({'fields': to_string(fields)})
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/comments/',
                        to_string(comment_id),
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, CommentFull)

    def update_comment_by_id(
        self,
        comment_id: str,
        *,
        message: Optional[str] = None,
        fields: Optional[List[str]] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> CommentFull:
        """
                Update the message of a comment.
                :param comment_id: The ID of the comment.
        Example: "12345"
                :type comment_id: str
                :param message: The text of the comment to update., defaults to None
                :type message: Optional[str], optional
                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested., defaults to None
                :type fields: Optional[List[str]], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'message': message}
        query_params_map: Dict[str, str] = prepare_params({'fields': to_string(fields)})
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/comments/',
                        to_string(comment_id),
                    ]
                ),
                method='PUT',
                params=query_params_map,
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, CommentFull)

    def delete_comment_by_id(
        self,
        comment_id: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> None:
        """
                Permanently deletes a comment.
                :param comment_id: The ID of the comment.
        Example: "12345"
                :type comment_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/comments/',
                        to_string(comment_id),
                    ]
                ),
                method='DELETE',
                headers=headers_map,
                response_format=ResponseFormat.NO_CONTENT,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return None

    def create_comment(
        self,
        message: str,
        item: CreateCommentItem,
        *,
        tagged_message: Optional[str] = None,
        fields: Optional[List[str]] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> CommentFull:
        """
                Adds a comment by the user to a specific file, or

                as a reply to an other comment.

                :param message: The text of the comment.

        To mention a user, use the `tagged_message`
        parameter instead.
                :type message: str
                :param item: The item to attach the comment to.
                :type item: CreateCommentItem
                :param tagged_message: The text of the comment, including `@[user_id:name]`
        somewhere in the message to mention another user, which
        will send them an email notification, letting them know
        they have been mentioned.

        The `user_id` is the target user's ID, where the `name`
        can be any custom phrase. In the Box UI this name will
        link to the user's profile.

        If you are not mentioning another user, use `message`
        instead., defaults to None
                :type tagged_message: Optional[str], optional
                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested., defaults to None
                :type fields: Optional[List[str]], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'message': message,
            'tagged_message': tagged_message,
            'item': item,
        }
        query_params_map: Dict[str, str] = prepare_params({'fields': to_string(fields)})
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join([self.network_session.base_urls.base_url, '/2.0/comments']),
                method='POST',
                params=query_params_map,
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, CommentFull)



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from typing import List

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.schemas.keyword_skill_card import KeywordSkillCard

from box_sdk_gen.schemas.timeline_skill_card import TimelineSkillCard

from box_sdk_gen.schemas.transcript_skill_card import TranscriptSkillCard

from box_sdk_gen.schemas.status_skill_card import StatusSkillCard

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.skill_cards_metadata import SkillCardsMetadata

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.schemas.skill_card import SkillCard

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData


class UpdateBoxSkillCardsOnFileRequestBodyOpField(str, Enum):
    REPLACE = 'replace'


class UpdateBoxSkillCardsOnFileRequestBody(BaseObject):
    def __init__(
        self,
        *,
        op: Optional[UpdateBoxSkillCardsOnFileRequestBodyOpField] = None,
        path: Optional[str] = None,
        value: Optional[SkillCard] = None,
        **kwargs
    ):
        """
                :param op: The value will always be `replace`., defaults to None
                :type op: Optional[UpdateBoxSkillCardsOnFileRequestBodyOpField], optional
                :param path: The JSON Path that represents the card to replace. In most cases
        this will be in the format `/cards/{index}` where `index` is the
        zero-indexed position of the card in the list of cards., defaults to None
                :type path: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.op = op
        self.path = path
        self.value = value


class UpdateAllSkillCardsOnFileStatus(str, Enum):
    INVOKED = 'invoked'
    PROCESSING = 'processing'
    SUCCESS = 'success'
    TRANSIENT_FAILURE = 'transient_failure'
    PERMANENT_FAILURE = 'permanent_failure'


class UpdateAllSkillCardsOnFileMetadata(BaseObject):
    def __init__(self, *, cards: Optional[List[SkillCard]] = None, **kwargs):
        """
        :param cards: A list of Box Skill cards to apply to this file., defaults to None
        :type cards: Optional[List[SkillCard]], optional
        """
        super().__init__(**kwargs)
        self.cards = cards


class UpdateAllSkillCardsOnFileFileTypeField(str, Enum):
    FILE = 'file'


class UpdateAllSkillCardsOnFileFile(BaseObject):
    _discriminator = 'type', {'file'}

    def __init__(
        self,
        *,
        type: Optional[UpdateAllSkillCardsOnFileFileTypeField] = None,
        id: Optional[str] = None,
        **kwargs
    ):
        """
        :param type: The value will always be `file`., defaults to None
        :type type: Optional[UpdateAllSkillCardsOnFileFileTypeField], optional
        :param id: The ID of the file., defaults to None
        :type id: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.type = type
        self.id = id


class UpdateAllSkillCardsOnFileFileVersionTypeField(str, Enum):
    FILE_VERSION = 'file_version'


class UpdateAllSkillCardsOnFileFileVersion(BaseObject):
    _discriminator = 'type', {'file_version'}

    def __init__(
        self,
        *,
        type: Optional[UpdateAllSkillCardsOnFileFileVersionTypeField] = None,
        id: Optional[str] = None,
        **kwargs
    ):
        """
        :param type: The value will always be `file_version`., defaults to None
        :type type: Optional[UpdateAllSkillCardsOnFileFileVersionTypeField], optional
        :param id: The ID of the file version., defaults to None
        :type id: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.type = type
        self.id = id


class UpdateAllSkillCardsOnFileUsage(BaseObject):
    def __init__(
        self, *, unit: Optional[str] = None, value: Optional[float] = None, **kwargs
    ):
        """
        :param unit: The value will always be `file`., defaults to None
        :type unit: Optional[str], optional
        :param value: Number of resources affected., defaults to None
        :type value: Optional[float], optional
        """
        super().__init__(**kwargs)
        self.unit = unit
        self.value = value


class SkillsManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def get_box_skill_cards_on_file(
        self, file_id: str, *, extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> SkillCardsMetadata:
        """
                List the Box Skills metadata cards that are attached to a file.
                :param file_id: The unique identifier that represents a file.

        The ID for any file can be determined
        by visiting a file in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/files/123`
        the `file_id` is `123`.
        Example: "12345"
                :type file_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/files/',
                        to_string(file_id),
                        '/metadata/global/boxSkillsCards',
                    ]
                ),
                method='GET',
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, SkillCardsMetadata)

    def create_box_skill_cards_on_file(
        self,
        file_id: str,
        cards: List[SkillCard],
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> SkillCardsMetadata:
        """
                Applies one or more Box Skills metadata cards to a file.
                :param file_id: The unique identifier that represents a file.

        The ID for any file can be determined
        by visiting a file in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/files/123`
        the `file_id` is `123`.
        Example: "12345"
                :type file_id: str
                :param cards: A list of Box Skill cards to apply to this file.
                :type cards: List[SkillCard]
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'cards': cards}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/files/',
                        to_string(file_id),
                        '/metadata/global/boxSkillsCards',
                    ]
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, SkillCardsMetadata)

    def update_box_skill_cards_on_file(
        self,
        file_id: str,
        request_body: List[UpdateBoxSkillCardsOnFileRequestBody],
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> SkillCardsMetadata:
        """
                Updates one or more Box Skills metadata cards to a file.
                :param file_id: The unique identifier that represents a file.

        The ID for any file can be determined
        by visiting a file in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/files/123`
        the `file_id` is `123`.
        Example: "12345"
                :type file_id: str
                :param request_body: Request body of updateBoxSkillCardsOnFile method
                :type request_body: List[UpdateBoxSkillCardsOnFileRequestBody]
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/files/',
                        to_string(file_id),
                        '/metadata/global/boxSkillsCards',
                    ]
                ),
                method='PUT',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json-patch+json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, SkillCardsMetadata)

    def delete_box_skill_cards_from_file(
        self, file_id: str, *, extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> None:
        """
                Removes any Box Skills cards metadata from a file.
                :param file_id: The unique identifier that represents a file.

        The ID for any file can be determined
        by visiting a file in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/files/123`
        the `file_id` is `123`.
        Example: "12345"
                :type file_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/files/',
                        to_string(file_id),
                        '/metadata/global/boxSkillsCards',
                    ]
                ),
                method='DELETE',
                headers=headers_map,
                response_format=ResponseFormat.NO_CONTENT,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return None

    def update_all_skill_cards_on_file(
        self,
        skill_id: str,
        status: UpdateAllSkillCardsOnFileStatus,
        metadata: UpdateAllSkillCardsOnFileMetadata,
        file: UpdateAllSkillCardsOnFileFile,
        *,
        file_version: Optional[UpdateAllSkillCardsOnFileFileVersion] = None,
        usage: Optional[UpdateAllSkillCardsOnFileUsage] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> None:
        """
                An alternative method that can be used to overwrite and update all Box Skill

                metadata cards on a file.

                :param skill_id: The ID of the skill to apply this metadata for.
        Example: "33243242"
                :type skill_id: str
                :param status: Defines the status of this invocation. Set this to `success` when setting Skill cards.
                :type status: UpdateAllSkillCardsOnFileStatus
                :param metadata: The metadata to set for this skill. This is a list of
        Box Skills cards. These cards will overwrite any existing Box
        skill cards on the file.
                :type metadata: UpdateAllSkillCardsOnFileMetadata
                :param file: The file to assign the cards to.
                :type file: UpdateAllSkillCardsOnFileFile
                :param file_version: The optional file version to assign the cards to., defaults to None
                :type file_version: Optional[UpdateAllSkillCardsOnFileFileVersion], optional
                :param usage: A descriptor that defines what items are affected by this call.

        Set this to the default values when setting a card to a `success`
        state, and leave it out in most other situations., defaults to None
                :type usage: Optional[UpdateAllSkillCardsOnFileUsage], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'status': status,
            'metadata': metadata,
            'file': file,
            'file_version': file_version,
            'usage': usage,
        }
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/skill_invocations/',
                        to_string(skill_id),
                    ]
                ),
                method='PUT',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.NO_CONTENT,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return None



from box_sdk_gen.networking.box_network_client import *

from box_sdk_gen.networking.timeout_config import *

from box_sdk_gen.networking.proxy_config import *

from box_sdk_gen.networking.network import *

from box_sdk_gen.networking.auth import *

from box_sdk_gen.networking.fetch_options import *

from box_sdk_gen.networking.fetch_response import *

from box_sdk_gen.networking.network_client import *

from box_sdk_gen.networking.retries import *

from box_sdk_gen.networking.base_urls import *

from box_sdk_gen.networking.version import *



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import deserialize

from typing import List

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.workflows import Workflows

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.schemas.outcome import Outcome

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData


class StartWorkflowType(str, Enum):
    WORKFLOW_PARAMETERS = 'workflow_parameters'


class StartWorkflowFlow(BaseObject):
    def __init__(
        self, *, type: Optional[str] = None, id: Optional[str] = None, **kwargs
    ):
        """
        :param type: The type of the flow object., defaults to None
        :type type: Optional[str], optional
        :param id: The id of the flow., defaults to None
        :type id: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.type = type
        self.id = id


class StartWorkflowFilesTypeField(str, Enum):
    FILE = 'file'


class StartWorkflowFiles(BaseObject):
    _discriminator = 'type', {'file'}

    def __init__(
        self,
        *,
        type: Optional[StartWorkflowFilesTypeField] = None,
        id: Optional[str] = None,
        **kwargs
    ):
        """
        :param type: The type of the file object., defaults to None
        :type type: Optional[StartWorkflowFilesTypeField], optional
        :param id: The id of the file., defaults to None
        :type id: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.type = type
        self.id = id


class StartWorkflowFolderTypeField(str, Enum):
    FOLDER = 'folder'


class StartWorkflowFolder(BaseObject):
    _discriminator = 'type', {'folder'}

    def __init__(
        self,
        *,
        type: Optional[StartWorkflowFolderTypeField] = None,
        id: Optional[str] = None,
        **kwargs
    ):
        """
        :param type: The type of the folder object., defaults to None
        :type type: Optional[StartWorkflowFolderTypeField], optional
        :param id: The id of the folder., defaults to None
        :type id: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.type = type
        self.id = id


class WorkflowsManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def get_workflows(
        self,
        folder_id: str,
        *,
        trigger_type: Optional[str] = None,
        limit: Optional[int] = None,
        marker: Optional[str] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> Workflows:
        """
                Returns list of workflows that act on a given `folder ID`, and

                have a flow with a trigger type of `WORKFLOW_MANUAL_START`.


                You application must be authorized to use the `Manage Box Relay` application


                scope within the developer console in to use this endpoint.

                :param folder_id: The unique identifier that represent a folder.

        The ID for any folder can be determined
        by visiting this folder in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/folder/123`
        the `folder_id` is `123`.

        The root folder of a Box account is
        always represented by the ID `0`.
                :type folder_id: str
                :param trigger_type: Type of trigger to search for., defaults to None
                :type trigger_type: Optional[str], optional
                :param limit: The maximum number of items to return per page., defaults to None
                :type limit: Optional[int], optional
                :param marker: Defines the position marker at which to begin returning results. This is
        used when paginating using marker-based pagination.

        This requires `usemarker` to be set to `true`., defaults to None
                :type marker: Optional[str], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {
                'folder_id': to_string(folder_id),
                'trigger_type': to_string(trigger_type),
                'limit': to_string(limit),
                'marker': to_string(marker),
            }
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [self.network_session.base_urls.base_url, '/2.0/workflows']
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, Workflows)

    def start_workflow(
        self,
        workflow_id: str,
        flow: StartWorkflowFlow,
        files: List[StartWorkflowFiles],
        folder: StartWorkflowFolder,
        *,
        type: Optional[StartWorkflowType] = None,
        outcomes: Optional[List[Outcome]] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> None:
        """
                Initiates a flow with a trigger type of `WORKFLOW_MANUAL_START`.

                You application must be authorized to use the `Manage Box Relay` application


                scope within the developer console.

                :param workflow_id: The ID of the workflow.
        Example: "12345"
                :type workflow_id: str
                :param flow: The flow that will be triggered.
                :type flow: StartWorkflowFlow
                :param files: The array of files for which the workflow should start. All files
        must be in the workflow's configured folder.
                :type files: List[StartWorkflowFiles]
                :param folder: The folder object for which the workflow is configured.
                :type folder: StartWorkflowFolder
                :param type: The type of the parameters object., defaults to None
                :type type: Optional[StartWorkflowType], optional
                :param outcomes: A configurable outcome the workflow should complete., defaults to None
                :type outcomes: Optional[List[Outcome]], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'type': type,
            'flow': flow,
            'files': files,
            'folder': folder,
            'outcomes': outcomes,
        }
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/workflows/',
                        to_string(workflow_id),
                        '/start',
                    ]
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.NO_CONTENT,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return None



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.ai_agent_basic_gen_tool import AiAgentBasicGenTool

from box_sdk_gen.box.errors import BoxSDKError


class AiAgentTextGenTypeField(str, Enum):
    AI_AGENT_TEXT_GEN = 'ai_agent_text_gen'


class AiAgentTextGen(BaseObject):
    _discriminator = 'type', {'ai_agent_text_gen'}

    def __init__(
        self,
        *,
        type: AiAgentTextGenTypeField = AiAgentTextGenTypeField.AI_AGENT_TEXT_GEN,
        basic_gen: Optional[AiAgentBasicGenTool] = None,
        **kwargs
    ):
        """
        :param type: The type of AI agent used for generating text., defaults to AiAgentTextGenTypeField.AI_AGENT_TEXT_GEN
        :type type: AiAgentTextGenTypeField, optional
        """
        super().__init__(**kwargs)
        self.type = type
        self.basic_gen = basic_gen



from typing import Union

from box_sdk_gen.schemas.user_base import UserBase

from box_sdk_gen.schemas.group_base import GroupBase

from box_sdk_gen.box.errors import BoxSDKError

AiAgentAllowedEntity = Union[UserBase, GroupBase]



from enum import Enum

from typing import Optional

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.v2025_r0.hubs_v2025_r0 import HubsV2025R0

from box_sdk_gen.schemas.v2025_r0.client_error_v2025_r0 import ClientErrorV2025R0

from box_sdk_gen.parameters.v2025_r0.box_version_header_v2025_r0 import (
    BoxVersionHeaderV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.hub_v2025_r0 import HubV2025R0

from box_sdk_gen.schemas.v2025_r0.hub_create_request_v2025_r0 import (
    HubCreateRequestV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.hub_update_request_v2025_r0 import (
    HubUpdateRequestV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.hub_copy_request_v2025_r0 import HubCopyRequestV2025R0

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData


class GetHubsV2025R0Direction(str, Enum):
    ASC = 'ASC'
    DESC = 'DESC'


class GetEnterpriseHubsV2025R0Direction(str, Enum):
    ASC = 'ASC'
    DESC = 'DESC'


class HubsManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def get_hubs_v2025_r0(
        self,
        *,
        query: Optional[str] = None,
        scope: Optional[str] = None,
        sort: Optional[str] = None,
        direction: Optional[GetHubsV2025R0Direction] = None,
        marker: Optional[str] = None,
        limit: Optional[int] = None,
        box_version: BoxVersionHeaderV2025R0 = BoxVersionHeaderV2025R0._2025_0,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> HubsV2025R0:
        """
                Retrieves all Box Hubs for requesting user.
                :param query: The query string to search for Box Hubs., defaults to None
                :type query: Optional[str], optional
                :param scope: The scope of the Box Hubs to retrieve. Possible values include `editable`,
        `view_only`, and `all`. Default is `all`., defaults to None
                :type scope: Optional[str], optional
                :param sort: The field to sort results by.
        Possible values include `name`, `updated_at`,
        `last_accessed_at`, `view_count`, and `relevance`.
        Default is `relevance`., defaults to None
                :type sort: Optional[str], optional
                :param direction: The direction to sort results in. This can be either in alphabetical ascending
        (`ASC`) or descending (`DESC`) order., defaults to None
                :type direction: Optional[GetHubsV2025R0Direction], optional
                :param marker: Defines the position marker at which to begin returning results. This is
        used when paginating using marker-based pagination., defaults to None
                :type marker: Optional[str], optional
                :param limit: The maximum number of items to return per page., defaults to None
                :type limit: Optional[int], optional
                :param box_version: Version header., defaults to BoxVersionHeaderV2025R0._2025_0
                :type box_version: BoxVersionHeaderV2025R0, optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {
                'query': to_string(query),
                'scope': to_string(scope),
                'sort': to_string(sort),
                'direction': to_string(direction),
                'marker': to_string(marker),
                'limit': to_string(limit),
            }
        )
        headers_map: Dict[str, str] = prepare_params(
            {'box-version': to_string(box_version), **extra_headers}
        )
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join([self.network_session.base_urls.base_url, '/2.0/hubs']),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, HubsV2025R0)

    def create_hub_v2025_r0(
        self,
        title: str,
        *,
        description: Optional[str] = None,
        box_version: BoxVersionHeaderV2025R0 = BoxVersionHeaderV2025R0._2025_0,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> HubV2025R0:
        """
        Creates a new Box Hub.
        :param title: Title of the Box Hub. It cannot be empty and should be less than 50 characters.
        :type title: str
        :param description: Description of the Box Hub., defaults to None
        :type description: Optional[str], optional
        :param box_version: Version header., defaults to BoxVersionHeaderV2025R0._2025_0
        :type box_version: BoxVersionHeaderV2025R0, optional
        :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
        :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'title': title, 'description': description}
        headers_map: Dict[str, str] = prepare_params(
            {'box-version': to_string(box_version), **extra_headers}
        )
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join([self.network_session.base_urls.base_url, '/2.0/hubs']),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, HubV2025R0)

    def get_enterprise_hubs_v2025_r0(
        self,
        *,
        query: Optional[str] = None,
        sort: Optional[str] = None,
        direction: Optional[GetEnterpriseHubsV2025R0Direction] = None,
        marker: Optional[str] = None,
        limit: Optional[int] = None,
        box_version: BoxVersionHeaderV2025R0 = BoxVersionHeaderV2025R0._2025_0,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> HubsV2025R0:
        """
                Retrieves all Box Hubs for a given enterprise.

                Admins or Hub Co-admins of an enterprise


                with GCM scope can make this call.

                :param query: The query string to search for Box Hubs., defaults to None
                :type query: Optional[str], optional
                :param sort: The field to sort results by.
        Possible values include `name`, `updated_at`,
        `last_accessed_at`, `view_count`, and `relevance`.
        Default is `relevance`., defaults to None
                :type sort: Optional[str], optional
                :param direction: The direction to sort results in. This can be either in alphabetical ascending
        (`ASC`) or descending (`DESC`) order., defaults to None
                :type direction: Optional[GetEnterpriseHubsV2025R0Direction], optional
                :param marker: Defines the position marker at which to begin returning results. This is
        used when paginating using marker-based pagination., defaults to None
                :type marker: Optional[str], optional
                :param limit: The maximum number of items to return per page., defaults to None
                :type limit: Optional[int], optional
                :param box_version: Version header., defaults to BoxVersionHeaderV2025R0._2025_0
                :type box_version: BoxVersionHeaderV2025R0, optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {
                'query': to_string(query),
                'sort': to_string(sort),
                'direction': to_string(direction),
                'marker': to_string(marker),
                'limit': to_string(limit),
            }
        )
        headers_map: Dict[str, str] = prepare_params(
            {'box-version': to_string(box_version), **extra_headers}
        )
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [self.network_session.base_urls.base_url, '/2.0/enterprise_hubs']
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, HubsV2025R0)

    def get_hub_by_id_v2025_r0(
        self,
        hub_id: str,
        *,
        box_version: BoxVersionHeaderV2025R0 = BoxVersionHeaderV2025R0._2025_0,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> HubV2025R0:
        """
                Retrieves details for a Box Hub by its ID.
                :param hub_id: The unique identifier that represent a hub.

        The ID for any hub can be determined
        by visiting this hub in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/hubs/123`
        the `hub_id` is `123`.
        Example: "12345"
                :type hub_id: str
                :param box_version: Version header., defaults to BoxVersionHeaderV2025R0._2025_0
                :type box_version: BoxVersionHeaderV2025R0, optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params(
            {'box-version': to_string(box_version), **extra_headers}
        )
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/hubs/',
                        to_string(hub_id),
                    ]
                ),
                method='GET',
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, HubV2025R0)

    def update_hub_by_id_v2025_r0(
        self,
        hub_id: str,
        *,
        title: Optional[str] = None,
        description: Optional[str] = None,
        is_ai_enabled: Optional[bool] = None,
        is_collaboration_restricted_to_enterprise: Optional[bool] = None,
        can_non_owners_invite: Optional[bool] = None,
        can_shared_link_be_created: Optional[bool] = None,
        can_public_shared_link_be_created: Optional[bool] = None,
        box_version: BoxVersionHeaderV2025R0 = BoxVersionHeaderV2025R0._2025_0,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> HubV2025R0:
        """
                Updates a Box Hub. Can be used to change title, description, or Box Hub settings.
                :param hub_id: The unique identifier that represent a hub.

        The ID for any hub can be determined
        by visiting this hub in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/hubs/123`
        the `hub_id` is `123`.
        Example: "12345"
                :type hub_id: str
                :param title: Title of the Box Hub. It cannot be empty and should be less than 50 characters., defaults to None
                :type title: Optional[str], optional
                :param description: Description of the Box Hub., defaults to None
                :type description: Optional[str], optional
                :param is_ai_enabled: Indicates if AI features are enabled for the Box Hub., defaults to None
                :type is_ai_enabled: Optional[bool], optional
                :param is_collaboration_restricted_to_enterprise: Indicates if collaboration is restricted to the enterprise., defaults to None
                :type is_collaboration_restricted_to_enterprise: Optional[bool], optional
                :param can_non_owners_invite: Indicates if non-owners can invite others to the Box Hub., defaults to None
                :type can_non_owners_invite: Optional[bool], optional
                :param can_shared_link_be_created: Indicates if a shared link can be created for the Box Hub., defaults to None
                :type can_shared_link_be_created: Optional[bool], optional
                :param can_public_shared_link_be_created: Indicates if a public shared link can be created for the Box Hub., defaults to None
                :type can_public_shared_link_be_created: Optional[bool], optional
                :param box_version: Version header., defaults to BoxVersionHeaderV2025R0._2025_0
                :type box_version: BoxVersionHeaderV2025R0, optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'title': title,
            'description': description,
            'is_ai_enabled': is_ai_enabled,
            'is_collaboration_restricted_to_enterprise': (
                is_collaboration_restricted_to_enterprise
            ),
            'can_non_owners_invite': can_non_owners_invite,
            'can_shared_link_be_created': can_shared_link_be_created,
            'can_public_shared_link_be_created': can_public_shared_link_be_created,
        }
        headers_map: Dict[str, str] = prepare_params(
            {'box-version': to_string(box_version), **extra_headers}
        )
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/hubs/',
                        to_string(hub_id),
                    ]
                ),
                method='PUT',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, HubV2025R0)

    def delete_hub_by_id_v2025_r0(
        self,
        hub_id: str,
        *,
        box_version: BoxVersionHeaderV2025R0 = BoxVersionHeaderV2025R0._2025_0,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> None:
        """
                Deletes a single Box Hub.
                :param hub_id: The unique identifier that represent a hub.

        The ID for any hub can be determined
        by visiting this hub in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/hubs/123`
        the `hub_id` is `123`.
        Example: "12345"
                :type hub_id: str
                :param box_version: Version header., defaults to BoxVersionHeaderV2025R0._2025_0
                :type box_version: BoxVersionHeaderV2025R0, optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params(
            {'box-version': to_string(box_version), **extra_headers}
        )
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/hubs/',
                        to_string(hub_id),
                    ]
                ),
                method='DELETE',
                headers=headers_map,
                response_format=ResponseFormat.NO_CONTENT,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return None

    def copy_hub_v2025_r0(
        self,
        hub_id: str,
        *,
        title: Optional[str] = None,
        description: Optional[str] = None,
        box_version: BoxVersionHeaderV2025R0 = BoxVersionHeaderV2025R0._2025_0,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> HubV2025R0:
        """
                Creates a copy of a Box Hub.

                The original Box Hub will not be modified.

                :param hub_id: The unique identifier that represent a hub.

        The ID for any hub can be determined
        by visiting this hub in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/hubs/123`
        the `hub_id` is `123`.
        Example: "12345"
                :type hub_id: str
                :param title: Title of the Box Hub. It cannot be empty and should be less than 50 characters., defaults to None
                :type title: Optional[str], optional
                :param description: Description of the Box Hub., defaults to None
                :type description: Optional[str], optional
                :param box_version: Version header., defaults to BoxVersionHeaderV2025R0._2025_0
                :type box_version: BoxVersionHeaderV2025R0, optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'title': title, 'description': description}
        headers_map: Dict[str, str] = prepare_params(
            {'box-version': to_string(box_version), **extra_headers}
        )
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/hubs/',
                        to_string(hub_id),
                        '/copy',
                    ]
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, HubV2025R0)



from typing import Optional

from typing import List

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.v2025_r0.enterprise_feature_settings_item_v2025_r0 import (
    EnterpriseFeatureSettingsItemV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.enterprise_configuration_item_string_v2025_r0 import (
    EnterpriseConfigurationItemStringV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.enterprise_configuration_item_boolean_v2025_r0 import (
    EnterpriseConfigurationItemBooleanV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.enterprise_configuration_item_integer_v2025_r0 import (
    EnterpriseConfigurationItemIntegerV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.enterprise_configuration_item_v2025_r0 import (
    EnterpriseConfigurationItemV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.user_tracking_code_v2025_r0 import (
    UserTrackingCodeV2025R0,
)

from box_sdk_gen.box.errors import BoxSDKError


class EnterpriseConfigurationUserSettingsV2025R0UserTrackingCodesField(
    EnterpriseConfigurationItemV2025R0
):
    def __init__(
        self,
        *,
        value: Optional[List[UserTrackingCodeV2025R0]] = None,
        is_used: Optional[bool] = None,
        **kwargs
    ):
        """
        :param is_used: Indicates whether a configuration is used for a given enterprise., defaults to None
        :type is_used: Optional[bool], optional
        """
        super().__init__(is_used=is_used, **kwargs)
        self.value = value


class EnterpriseConfigurationUserSettingsV2025R0(BaseObject):
    def __init__(
        self,
        *,
        enterprise_feature_settings: Optional[
            List[EnterpriseFeatureSettingsItemV2025R0]
        ] = None,
        user_invites_expiration_time_frame: Optional[
            EnterpriseConfigurationItemStringV2025R0
        ] = None,
        is_username_change_restricted: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        is_box_sync_restricted_for_new_users: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        is_view_all_users_enabled_for_new_users: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        is_device_limit_exemption_enabled_for_new_users: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        is_external_collaboration_restricted_for_new_users: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        is_unlimited_storage_enabled_for_new_users: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        new_user_default_storage_limit: Optional[
            EnterpriseConfigurationItemIntegerV2025R0
        ] = None,
        new_user_default_timezone: Optional[
            EnterpriseConfigurationItemStringV2025R0
        ] = None,
        new_user_default_language: Optional[
            EnterpriseConfigurationItemStringV2025R0
        ] = None,
        is_enterprise_sso_required: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        is_enterprise_sso_in_testing: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        is_sso_auto_add_groups_enabled: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        is_sso_auto_add_user_to_groups_enabled: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        is_sso_auto_remove_user_from_groups_enabled: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        user_tracking_codes: Optional[
            EnterpriseConfigurationUserSettingsV2025R0UserTrackingCodesField
        ] = None,
        number_of_user_tracking_codes_remaining: Optional[
            EnterpriseConfigurationItemIntegerV2025R0
        ] = None,
        is_instant_login_restricted: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        **kwargs
    ):
        super().__init__(**kwargs)
        self.enterprise_feature_settings = enterprise_feature_settings
        self.user_invites_expiration_time_frame = user_invites_expiration_time_frame
        self.is_username_change_restricted = is_username_change_restricted
        self.is_box_sync_restricted_for_new_users = is_box_sync_restricted_for_new_users
        self.is_view_all_users_enabled_for_new_users = (
            is_view_all_users_enabled_for_new_users
        )
        self.is_device_limit_exemption_enabled_for_new_users = (
            is_device_limit_exemption_enabled_for_new_users
        )
        self.is_external_collaboration_restricted_for_new_users = (
            is_external_collaboration_restricted_for_new_users
        )
        self.is_unlimited_storage_enabled_for_new_users = (
            is_unlimited_storage_enabled_for_new_users
        )
        self.new_user_default_storage_limit = new_user_default_storage_limit
        self.new_user_default_timezone = new_user_default_timezone
        self.new_user_default_language = new_user_default_language
        self.is_enterprise_sso_required = is_enterprise_sso_required
        self.is_enterprise_sso_in_testing = is_enterprise_sso_in_testing
        self.is_sso_auto_add_groups_enabled = is_sso_auto_add_groups_enabled
        self.is_sso_auto_add_user_to_groups_enabled = (
            is_sso_auto_add_user_to_groups_enabled
        )
        self.is_sso_auto_remove_user_from_groups_enabled = (
            is_sso_auto_remove_user_from_groups_enabled
        )
        self.user_tracking_codes = user_tracking_codes
        self.number_of_user_tracking_codes_remaining = (
            number_of_user_tracking_codes_remaining
        )
        self.is_instant_login_restricted = is_instant_login_restricted



from typing import Optional

from typing import List

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.integration_mapping import IntegrationMapping

from box_sdk_gen.box.errors import BoxSDKError


class IntegrationMappings(BaseObject):
    def __init__(
        self,
        *,
        limit: Optional[int] = None,
        next_marker: Optional[str] = None,
        entries: Optional[List[IntegrationMapping]] = None,
        **kwargs
    ):
        """
                :param limit: The limit that was used for these entries. This will be the same as the
        `limit` query parameter unless that value exceeded the maximum value
        allowed. The maximum value varies by API., defaults to None
                :type limit: Optional[int], optional
                :param next_marker: The marker for the start of the next page of results., defaults to None
                :type next_marker: Optional[str], optional
                :param entries: A list of integration mappings., defaults to None
                :type entries: Optional[List[IntegrationMapping]], optional
        """
        super().__init__(**kwargs)
        self.limit = limit
        self.next_marker = next_marker
        self.entries = entries



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from typing import List

from box_sdk_gen.schemas.retention_policy_base import RetentionPolicyBaseTypeField

from box_sdk_gen.schemas.retention_policy_base import RetentionPolicyBase

from box_sdk_gen.schemas.retention_policy_mini import (
    RetentionPolicyMiniDispositionActionField,
)

from box_sdk_gen.schemas.retention_policy_mini import RetentionPolicyMini

from box_sdk_gen.schemas.user_mini import UserMini

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class RetentionPolicyPolicyTypeField(str, Enum):
    FINITE = 'finite'
    INDEFINITE = 'indefinite'


class RetentionPolicyRetentionTypeField(str, Enum):
    MODIFIABLE = 'modifiable'
    NON_MODIFIABLE = 'non_modifiable'


class RetentionPolicyStatusField(str, Enum):
    ACTIVE = 'active'
    RETIRED = 'retired'


class RetentionPolicyAssignmentCountsField(BaseObject):
    def __init__(
        self,
        *,
        enterprise: Optional[int] = None,
        folder: Optional[int] = None,
        metadata_template: Optional[int] = None,
        **kwargs
    ):
        """
        :param enterprise: The number of enterprise assignments this policy has. The maximum value is 1., defaults to None
        :type enterprise: Optional[int], optional
        :param folder: The number of folder assignments this policy has., defaults to None
        :type folder: Optional[int], optional
        :param metadata_template: The number of metadata template assignments this policy has., defaults to None
        :type metadata_template: Optional[int], optional
        """
        super().__init__(**kwargs)
        self.enterprise = enterprise
        self.folder = folder
        self.metadata_template = metadata_template


class RetentionPolicy(RetentionPolicyMini):
    def __init__(
        self,
        id: str,
        *,
        description: Optional[str] = None,
        policy_type: Optional[RetentionPolicyPolicyTypeField] = None,
        retention_type: Optional[RetentionPolicyRetentionTypeField] = None,
        status: Optional[RetentionPolicyStatusField] = None,
        created_by: Optional[UserMini] = None,
        created_at: Optional[DateTime] = None,
        modified_at: Optional[DateTime] = None,
        can_owner_extend_retention: Optional[bool] = None,
        are_owners_notified: Optional[bool] = None,
        custom_notification_recipients: Optional[List[UserMini]] = None,
        assignment_counts: Optional[RetentionPolicyAssignmentCountsField] = None,
        policy_name: Optional[str] = None,
        retention_length: Optional[str] = None,
        disposition_action: Optional[RetentionPolicyMiniDispositionActionField] = None,
        type: RetentionPolicyBaseTypeField = RetentionPolicyBaseTypeField.RETENTION_POLICY,
        **kwargs
    ):
        """
                :param id: The unique identifier that represents a retention policy.
                :type id: str
                :param description: The additional text description of the retention policy., defaults to None
                :type description: Optional[str], optional
                :param policy_type: The type of the retention policy. A retention
        policy type can either be `finite`, where a
        specific amount of time to retain the content is known
        upfront, or `indefinite`, where the amount of time
        to retain the content is still unknown., defaults to None
                :type policy_type: Optional[RetentionPolicyPolicyTypeField], optional
                :param retention_type: Specifies the retention type:

        * `modifiable`: You can modify the retention policy. For example,
         you can add or remove folders, shorten or lengthen
         the policy duration, or delete the assignment.
         Use this type if your retention policy
         is not related to any regulatory purposes.

        * `non-modifiable`: You can modify the retention policy
         only in a limited way: add a folder, lengthen the duration,
         retire the policy, change the disposition action
         or notification settings. You cannot perform other actions,
         such as deleting the assignment or shortening the
         policy duration. Use this type to ensure
         compliance with regulatory retention policies., defaults to None
                :type retention_type: Optional[RetentionPolicyRetentionTypeField], optional
                :param status: The status of the retention policy. The status of
        a policy will be `active`, unless explicitly retired by an
        administrator, in which case the status will be `retired`.
        Once a policy has been retired, it cannot become
        active again., defaults to None
                :type status: Optional[RetentionPolicyStatusField], optional
                :param created_at: When the retention policy object was created., defaults to None
                :type created_at: Optional[DateTime], optional
                :param modified_at: When the retention policy object was last modified., defaults to None
                :type modified_at: Optional[DateTime], optional
                :param can_owner_extend_retention: Determines if the owner of items under the policy
        can extend the retention when the original
        retention duration is about to end., defaults to None
                :type can_owner_extend_retention: Optional[bool], optional
                :param are_owners_notified: Determines if owners and co-owners of items
        under the policy are notified when
        the retention duration is about to end., defaults to None
                :type are_owners_notified: Optional[bool], optional
                :param custom_notification_recipients: A list of users notified when the retention policy duration is about to end., defaults to None
                :type custom_notification_recipients: Optional[List[UserMini]], optional
                :param assignment_counts: Counts the retention policy assignments for each item type., defaults to None
                :type assignment_counts: Optional[RetentionPolicyAssignmentCountsField], optional
                :param policy_name: The name given to the retention policy., defaults to None
                :type policy_name: Optional[str], optional
                :param retention_length: The length of the retention policy. This value
        specifies the duration in days that the retention
        policy will be active for after being assigned to
        content.  If the policy has a `policy_type` of
        `indefinite`, the `retention_length` will also be
        `indefinite`., defaults to None
                :type retention_length: Optional[str], optional
                :param disposition_action: The disposition action of the retention policy.
        This action can be `permanently_delete`, which
        will cause the content retained by the policy
        to be permanently deleted, or `remove_retention`,
        which will lift the retention policy from the content,
        allowing it to be deleted by users,
        once the retention policy has expired., defaults to None
                :type disposition_action: Optional[RetentionPolicyMiniDispositionActionField], optional
                :param type: The value will always be `retention_policy`., defaults to RetentionPolicyBaseTypeField.RETENTION_POLICY
                :type type: RetentionPolicyBaseTypeField, optional
        """
        super().__init__(
            id=id,
            policy_name=policy_name,
            retention_length=retention_length,
            disposition_action=disposition_action,
            type=type,
            **kwargs
        )
        self.description = description
        self.policy_type = policy_type
        self.retention_type = retention_type
        self.status = status
        self.created_by = created_by
        self.created_at = created_at
        self.modified_at = modified_at
        self.can_owner_extend_retention = can_owner_extend_retention
        self.are_owners_notified = are_owners_notified
        self.custom_notification_recipients = custom_notification_recipients
        self.assignment_counts = assignment_counts



from typing import Union

from box_sdk_gen.schemas.v2025_r0.hub_collaboration_user_v2025_r0 import (
    HubCollaborationUserV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.group_mini_v2025_r0 import GroupMiniV2025R0

from box_sdk_gen.box.errors import BoxSDKError

HubAccessGranteeV2025R0 = Union[HubCollaborationUserV2025R0, GroupMiniV2025R0]



from enum import Enum

from typing import Optional

from typing import Dict

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class ClientErrorV2025R0TypeField(str, Enum):
    ERROR = 'error'


class ClientErrorV2025R0CodeField(str, Enum):
    CREATED = 'created'
    ACCEPTED = 'accepted'
    NO_CONTENT = 'no_content'
    REDIRECT = 'redirect'
    NOT_MODIFIED = 'not_modified'
    BAD_REQUEST = 'bad_request'
    UNAUTHORIZED = 'unauthorized'
    FORBIDDEN = 'forbidden'
    NOT_FOUND = 'not_found'
    METHOD_NOT_ALLOWED = 'method_not_allowed'
    CONFLICT = 'conflict'
    PRECONDITION_FAILED = 'precondition_failed'
    TOO_MANY_REQUESTS = 'too_many_requests'
    INTERNAL_SERVER_ERROR = 'internal_server_error'
    UNAVAILABLE = 'unavailable'
    ITEM_NAME_INVALID = 'item_name_invalid'
    INSUFFICIENT_SCOPE = 'insufficient_scope'


class ClientErrorV2025R0(BaseObject):
    _discriminator = 'type', {'error'}

    def __init__(
        self,
        *,
        type: Optional[ClientErrorV2025R0TypeField] = None,
        status: Optional[int] = None,
        code: Optional[ClientErrorV2025R0CodeField] = None,
        message: Optional[str] = None,
        context_info: Optional[Dict] = None,
        help_url: Optional[str] = None,
        request_id: Optional[str] = None,
        **kwargs
    ):
        """
                :param type: The value will always be `error`., defaults to None
                :type type: Optional[ClientErrorV2025R0TypeField], optional
                :param status: The HTTP status of the response., defaults to None
                :type status: Optional[int], optional
                :param code: A Box-specific error code., defaults to None
                :type code: Optional[ClientErrorV2025R0CodeField], optional
                :param message: A short message describing the error., defaults to None
                :type message: Optional[str], optional
                :param context_info: A free-form object that contains additional context
        about the error. The possible fields are defined on
        a per-endpoint basis. `message` is only one example., defaults to None
                :type context_info: Optional[Dict], optional
                :param help_url: A URL that links to more information about why this error occurred., defaults to None
                :type help_url: Optional[str], optional
                :param request_id: A unique identifier for this response, which can be used
        when contacting Box support., defaults to None
                :type request_id: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.type = type
        self.status = status
        self.code = code
        self.message = message
        self.context_info = context_info
        self.help_url = help_url
        self.request_id = request_id



from enum import Enum

from box_sdk_gen.internal.base_object import BaseObject

from typing import Optional

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.watermark import Watermark

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData


class UpdateFolderWatermarkWatermarkImprintField(str, Enum):
    DEFAULT = 'default'


class UpdateFolderWatermarkWatermark(BaseObject):
    def __init__(
        self,
        *,
        imprint: UpdateFolderWatermarkWatermarkImprintField = UpdateFolderWatermarkWatermarkImprintField.DEFAULT,
        **kwargs
    ):
        """
                :param imprint: The type of watermark to apply.

        Currently only supports one option., defaults to UpdateFolderWatermarkWatermarkImprintField.DEFAULT
                :type imprint: UpdateFolderWatermarkWatermarkImprintField, optional
        """
        super().__init__(**kwargs)
        self.imprint = imprint


class FolderWatermarksManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def get_folder_watermark(
        self,
        folder_id: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> Watermark:
        """
                Retrieve the watermark for a folder.
                :param folder_id: The unique identifier that represent a folder.

        The ID for any folder can be determined
        by visiting this folder in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/folder/123`
        the `folder_id` is `123`.

        The root folder of a Box account is
        always represented by the ID `0`.
        Example: "12345"
                :type folder_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/folders/',
                        to_string(folder_id),
                        '/watermark',
                    ]
                ),
                method='GET',
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, Watermark)

    def update_folder_watermark(
        self,
        folder_id: str,
        watermark: UpdateFolderWatermarkWatermark,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> Watermark:
        """
                Applies or update a watermark on a folder.
                :param folder_id: The unique identifier that represent a folder.

        The ID for any folder can be determined
        by visiting this folder in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/folder/123`
        the `folder_id` is `123`.

        The root folder of a Box account is
        always represented by the ID `0`.
        Example: "12345"
                :type folder_id: str
                :param watermark: The watermark to imprint on the folder.
                :type watermark: UpdateFolderWatermarkWatermark
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'watermark': watermark}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/folders/',
                        to_string(folder_id),
                        '/watermark',
                    ]
                ),
                method='PUT',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, Watermark)

    def delete_folder_watermark(
        self,
        folder_id: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> None:
        """
                Removes the watermark from a folder.
                :param folder_id: The unique identifier that represent a folder.

        The ID for any folder can be determined
        by visiting this folder in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/folder/123`
        the `folder_id` is `123`.

        The root folder of a Box account is
        always represented by the ID `0`.
        Example: "12345"
                :type folder_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/folders/',
                        to_string(folder_id),
                        '/watermark',
                    ]
                ),
                method='DELETE',
                headers=headers_map,
                response_format=ResponseFormat.NO_CONTENT,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return None



from typing import Optional

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.schemas.user_avatar import UserAvatar

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.networking.fetch_options import MultipartItem

from box_sdk_gen.serialization.json import SerializedData


class AvatarsManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def get_user_avatar(
        self, user_id: str, *, extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> ByteStream:
        """
                Retrieves an image of a the user's avatar.
                :param user_id: The ID of the user.
        Example: "12345"
                :type user_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/users/',
                        to_string(user_id),
                        '/avatar',
                    ]
                ),
                method='GET',
                headers=headers_map,
                response_format=ResponseFormat.BINARY,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return response.content

    def create_user_avatar(
        self,
        user_id: str,
        pic: ByteStream,
        *,
        pic_file_name: Optional[str] = None,
        pic_content_type: Optional[str] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> UserAvatar:
        """
                Adds or updates a user avatar.
                :param user_id: The ID of the user.
        Example: "12345"
                :type user_id: str
                :param pic: The image file to be uploaded to Box.
        Accepted file extensions are `.jpg` or `.png`.
        The maximum file size is 1MB.
                :type pic: ByteStream
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'pic': pic,
            'pic_file_name': pic_file_name,
            'pic_content_type': pic_content_type,
        }
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/users/',
                        to_string(user_id),
                        '/avatar',
                    ]
                ),
                method='POST',
                headers=headers_map,
                multipart_data=[
                    MultipartItem(
                        part_name='pic',
                        file_stream=pic,
                        file_name=pic_file_name,
                        content_type=pic_content_type,
                    )
                ],
                content_type='multipart/form-data',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, UserAvatar)

    def delete_user_avatar(
        self, user_id: str, *, extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> None:
        """
                Removes an existing user avatar.

                You cannot reverse this operation.

                :param user_id: The ID of the user.
        Example: "12345"
                :type user_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/users/',
                        to_string(user_id),
                        '/avatar',
                    ]
                ),
                method='DELETE',
                headers=headers_map,
                response_format=ResponseFormat.NO_CONTENT,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return None



from box_sdk_gen.schemas.v2025_r0.archive_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.archives_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.client_error_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.collaboration_permissions_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.custom_session_duration_group_item_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.doc_gen_batch_base_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.doc_gen_document_generation_data_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.doc_gen_job_base_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.doc_gen_tag_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.doc_gen_tags_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.doc_gen_tags_processing_message_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.enterprise_configuration_item_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.enterprise_configuration_item_string_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.enterprise_configuration_item_integer_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.enterprise_configuration_item_boolean_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.enterprise_reference_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.external_collab_security_settings_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.external_user_deletion_result_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.external_users_submit_delete_job_response_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.file_reference_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.doc_gen_template_create_request_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.doc_gen_template_base_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.doc_gen_template_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.doc_gen_templates_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.file_version_base_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.doc_gen_job_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.doc_gen_jobs_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.doc_gen_batch_create_request_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.folder_reference_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.group_base_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.group_mini_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.hub_base_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.hub_collaboration_create_request_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.hub_collaboration_update_request_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.hub_copy_request_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.hub_create_request_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.hub_item_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.hub_items_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.hub_update_request_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.keysafe_settings_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.enterprise_configuration_security_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.list_user_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.shared_link_permissions_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.shield_list_mini_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.shield_lists_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.shield_list_content_country_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.shield_list_content_domain_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.shield_list_content_email_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.shield_list_content_integration_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.shield_list_content_ip_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.shield_list_content_request_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.shield_lists_update_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.shield_lists_create_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.shield_list_content_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.shield_list_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.shield_rule_item_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.enterprise_configuration_shield_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.terms_of_service_base_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.user_base_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.user_mini_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.hub_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.hubs_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.hub_collaboration_user_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.hub_access_grantee_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.hub_collaboration_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.hub_collaborations_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.doc_gen_job_full_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.doc_gen_jobs_full_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.user_or_group_reference_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.enterprise_feature_setting_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.enterprise_feature_settings_item_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.enterprise_configuration_content_and_sharing_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.user_reference_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.external_users_submit_delete_job_request_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.user_tracking_code_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.enterprise_configuration_user_settings_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.enterprise_configuration_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.weblink_reference_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.hub_item_reference_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.hub_item_operation_result_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.hub_items_manage_response_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.hub_item_operation_v2025_r0 import *

from box_sdk_gen.schemas.v2025_r0.hub_items_manage_request_v2025_r0 import *



from enum import Enum

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class AppItemTypeField(str, Enum):
    APP_ITEM = 'app_item'


class AppItem(BaseObject):
    _discriminator = 'type', {'app_item'}

    def __init__(
        self,
        id: str,
        application_type: str,
        *,
        type: AppItemTypeField = AppItemTypeField.APP_ITEM,
        **kwargs
    ):
        """
        :param id: The unique identifier for this app item.
        :type id: str
        :param application_type: The type of the app that owns this app item.
        :type application_type: str
        :param type: The value will always be `app_item`., defaults to AppItemTypeField.APP_ITEM
        :type type: AppItemTypeField, optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.application_type = application_type
        self.type = type



from typing import Optional

from abc import abstractmethod

from typing import List

from box_sdk_gen.schemas.access_token import AccessToken

from box_sdk_gen.networking.network import NetworkSession


class Authentication:
    def __init__(self):
        pass

    @abstractmethod
    def retrieve_token(
        self, *, network_session: Optional[NetworkSession] = None
    ) -> AccessToken:
        pass

    @abstractmethod
    def refresh_token(
        self, *, network_session: Optional[NetworkSession] = None
    ) -> AccessToken:
        pass

    @abstractmethod
    def retrieve_authorization_header(
        self, *, network_session: Optional[NetworkSession] = None
    ) -> str:
        pass

    @abstractmethod
    def revoke_token(self, *, network_session: Optional[NetworkSession] = None) -> None:
        pass

    @abstractmethod
    def downscope_token(
        self,
        scopes: List[str],
        *,
        resource: Optional[str] = None,
        shared_link: Optional[str] = None,
        network_session: Optional[NetworkSession] = None
    ) -> AccessToken:
        pass
